==> aleph-1.0.20-py3-none-any.whl: aleph/gui/ui_decomposition.py <==
from PySide2 import QtWidgets, QtCore, QtWebEngineWidgets, QtGui
from OpenGL import GL

import os

class Ui_Decomposition:
	def setupUI(self, Decomposition):

		self.gridLayout = QtWidgets.QGridLayout(Decomposition)
		self.gridLayout.setObjectName("gridLayout")

		self.splitter = QtWidgets.QSplitter(Decomposition)
		self.splitter.setObjectName("splitter")
		self.splitter.setOrientation(QtCore.Qt.Vertical)
		self.splitter.setHandleWidth(15)
		#self.splitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter.png")+");}");

		self.topGroupBox = QtWidgets.QGroupBox(self.splitter)
		self.topGroupBox.setObjectName("topGroupBox")
		self.topGroupBox.setTitle("Decomposition in compact groups")

		self.topLayout = QtWidgets.QGridLayout(self.topGroupBox)
		self.topLayout.setObjectName("topLayout")

		self.titleLabel = QtWidgets.QLabel(self.topGroupBox)
		self.titleLabel.setObjectName("titleLabel")
		self.titleLabel.setText("Job title")
		self.topLayout.addWidget(self.titleLabel, 0, 0, 1, 1)
		self.titleLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.titleLine.setObjectName("titleLine")
		self.titleLine.setFixedWidth(150)
		self.topLayout.addWidget(self.titleLine, 0, 1, 1, 1)

		self.pdbLabel = QtWidgets.QLabel(self.topGroupBox)
		self.pdbLabel.setObjectName("pdbLabel")
		self.pdbLabel.setText("Pdb")
		self.topLayout.addWidget(self.pdbLabel, 1, 0, 1, 1)
		self.pdbLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.pdbLine.setObjectName("pdbLine")
		self.topLayout.addWidget(self.pdbLine, 1, 1, 1, 1)
		self.pdbLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.pdbLoad.setObjectName("pdbLoad")
		self.pdbLoad.setText("Browse")
		self.topLayout.addWidget(self.pdbLoad, 1, 2, 1, 1)

		self.homogeinityCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.homogeinityCheck.setObjectName("homogeinityCheck")
		self.homogeinityCheck.setText("Homogeneity")
		self.topLayout.addWidget(self.homogeinityCheck, 2, 0, 1, 2)

		self.packCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.packCheck.setObjectName("packCheck")
		self.packCheck.setText("Pack beta sheet")
		self.topLayout.addWidget(self.packCheck, 3, 0, 1, 2)

		self.iterativeCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.iterativeCheck.setObjectName("iterativeCheck")
		self.iterativeCheck.setText("Iterative hierarchical clustering")
		self.topLayout.addWidget(self.iterativeCheck, 4, 0, 1, 2)

		self.line = QtWidgets.QFrame(self.topGroupBox)
		self.line.setFrameShape(QtWidgets.QFrame.VLine)
		self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line.setObjectName("line")
		self.topLayout.addWidget(self.line, 0, 3, 5, 1)

		self.alphaLabel = QtWidgets.QLabel(self.topGroupBox)
		self.alphaLabel.setObjectName("alphaLabel")
		self.alphaLabel.setText("strictness alpha")
		self.topLayout.addWidget(self.alphaLabel, 0, 4, 1, 1)
		self.alphaSlider = QtWidgets.QSlider(self.topGroupBox)
		self.alphaSlider.setObjectName("alphaSlider")
		self.alphaSlider.setOrientation(QtCore.Qt.Horizontal)
		self.alphaSlider.setMinimum(0)
		self.alphaSlider.setMaximum(100)
		self.alphaSlider.setSingleStep(10)
		self.alphaSlider.setValue(50)
		self.topLayout.addWidget(self.alphaSlider, 0, 5, 1, 1)
		self.alphaValue = QtWidgets.QLabel(self.topGroupBox)
		self.alphaValue.setObjectName("valueAlpha")
		self.alphaValue.setText("0,50")
		self.topLayout.addWidget(self.alphaValue, 0, 6, 1, 1)

		self.betaLabel = QtWidgets.QLabel(self.topGroupBox)
		self.betaLabel.setObjectName("betaLabel")
		self.betaLabel.setText("strictness beta")
		self.topLayout.addWidget(self.betaLabel, 1, 4, 1, 1)
		self.betaSlider = QtWidgets.QSlider(self.topGroupBox)
		self.betaSlider.setObjectName("betaSlider")
		self.betaSlider.setOrientation(QtCore.Qt.Horizontal)
		self.betaSlider.setMinimum(0)
		self.betaSlider.setMaximum(100)
		self.betaSlider.setSingleStep(10)
		self.betaSlider.setValue(30)
		self.topLayout.addWidget(self.betaSlider, 1, 5, 1, 1)
		self.betaValue = QtWidgets.QLabel(self.topGroupBox)
		self.betaValue.setObjectName("betaValue")
		self.betaValue.setText("0,30")
		self.topLayout.addWidget(self.betaValue, 1, 6, 1, 1)

		self.algorithmLabel = QtWidgets.QLabel(self.topGroupBox)
		self.algorithmLabel.setObjectName("algorithmLabel")
		self.algorithmLabel.setText("Algorithm")
		self.topLayout.addWidget(self.algorithmLabel, 2, 4, 1, 1)	
		self.algorithmValue = QtWidgets.QComboBox(self.topGroupBox)
		self.algorithmValue.setObjectName("algorithmValue")
		self.algorithmValue.addItems(["fastgreedy" , "infomap" ,"eigenvectors" ,"label_propagation" ,"community_multilevel" ,"edge_betweenness" ,"spinglass" ,"walktrap"])
		self.topLayout.addWidget(self.algorithmValue, 2, 5, 1, 1)
		
		self.tabs = QtWidgets.QTabWidget(self.splitter)
		self.tabs.setObjectName("tabs")

		self.middleSplitter = QtWidgets.QSplitter(self.tabs)
		self.middleSplitter.setObjectName("middleSplitter")
		self.middleSplitter.setOrientation(QtCore.Qt.Horizontal)
		self.middleSplitter.setHandleWidth(10)
		#self.middleSplitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter_h.png")+");}");
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.middleSplitter.setSizePolicy(policy)

		self.tabs.addTab(self.middleSplitter, "General")
		
		self.tree = QtWidgets.QTreeView(self.middleSplitter)
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
		self.tree.setSizePolicy(policy)
		self.model = QtWidgets.QFileSystemModel(self.tree)
		self.tree.setModel(self.model)
		self.model.setNameFilters(["*.pdb", "*.ent"])
		self.model.setNameFilterDisables(False)
		self.tree.hideColumn(1)
		self.tree.hideColumn(2)
		self.tree.header().hide()
		self.tree.header().setSectionResizeMode(QtWidgets.QHeaderView.Stretch)
		self.tree.sortByColumn(3, QtCore.Qt.AscendingOrder)
		self.tree.setSortingEnabled(True)
		
		self.structureLayoutWidget = QtWidgets.QWidget(self.middleSplitter)
		self.structureLayoutWidget.setObjectName("structureLayoutWidget")

		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.structureLayoutWidget.setSizePolicy(policy)

		self.structureLayout = QtWidgets.QGridLayout(self.structureLayoutWidget)
		self.structureLayout.setObjectName("structureLayout")
		self.structureLayout.setContentsMargins(0, 0, 0, 0)

		self.browserLabel = QtWidgets.QLabel(self.structureLayoutWidget)
		self.browserLabel.setObjectName("browserLabel")
		self.browserLabel.setText("Decomposed model")
		self.structureLayout.addWidget(self.browserLabel, 0, 0, 1, 12)		

		self.browser = QtWebEngineWidgets.QWebEngineView(self.structureLayoutWidget)
		self.browser.setObjectName("browser")
		self.browser.page().setBackgroundColor(QtCore.Qt.black)
		self.browser.setSizePolicy(policy)

		self.structureLayout.addWidget(self.browser, 1, 0, 1, 12)

		spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
		self.structureLayout.addItem(spacerItem, 2, 0, 1, 1)

		self.representationLabel = QtWidgets.QLabel(self.structureLayoutWidget)
		self.representationLabel.setObjectName("representationLabel")
		self.representationLabel.setText("Representation")
		self.structureLayout.addWidget(self.representationLabel, 2, 1, 1, 1)
		self.representationValue = QtWidgets.QComboBox(self.structureLayoutWidget)
		self.representationValue.setObjectName("representationValue")
		self.representationValue.addItems(["cartoon" , "backbone", "licorice"])
		self.structureLayout.addWidget(self.representationValue, 2, 2, 1, 1)

		self.line1 = QtWidgets.QFrame(self.structureLayoutWidget)
		self.line1.setFrameShape(QtWidgets.QFrame.VLine)
		self.line1.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line1.setObjectName("line1")
		self.structureLayout.addWidget(self.line1, 2, 3, 1, 1)

		self.templateCheck = QtWidgets.QCheckBox(self.structureLayoutWidget)
		self.templateCheck.setObjectName("templateCheck")
		self.templateCheck.setText("Show template")
		self.structureLayout.addWidget(self.templateCheck, 2, 4, 1, 1)
		self.templateValue = QtWidgets.QComboBox(self.structureLayoutWidget)
		self.templateValue.setObjectName("templateValue")
		self.templateValue.addItems(["trace" , "line"])
		self.structureLayout.addWidget(self.templateValue, 2, 5, 1, 1)

		self.line2 = QtWidgets.QFrame(self.structureLayoutWidget)
		self.line2.setFrameShape(QtWidgets.QFrame.VLine)
		self.line2.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line2.setObjectName("line2")
		self.structureLayout.addWidget(self.line2, 2, 6, 1, 1)

		self.numberLabel = QtWidgets.QLabel(self.structureLayoutWidget)
		self.numberLabel.setObjectName("numberLabel")
		self.numberLabel.setText("Division cut to")
		self.structureLayout.addWidget(self.numberLabel, 2, 7, 1, 1)
		self.numberValue = QtWidgets.QSpinBox(self.structureLayoutWidget)
		self.numberValue.setObjectName("maxRmsdValue")
		self.numberValue.setValue(0)
		self.numberValue.setMaximum(999)
		self.numberValue.setEnabled(False)
		self.structureLayout.addWidget(self.numberValue, 2, 8, 1, 1)
		self.number2Label = QtWidgets.QLabel(self.structureLayoutWidget)
		self.number2Label.setObjectName("number2Label")
		self.number2Label.setText("cluster")
		self.structureLayout.addWidget(self.number2Label, 2, 9, 1, 1)

		self.line3 = QtWidgets.QFrame(self.structureLayoutWidget)
		self.line3.setFrameShape(QtWidgets.QFrame.VLine)
		self.line3.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line3.setObjectName("line3")
		self.structureLayout.addWidget(self.line3, 2, 10, 1, 1)

		self.saveButton = QtWidgets.QPushButton(self.structureLayoutWidget)
		self.saveButton.setObjectName("saveButton")
		self.saveButton.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
		self.structureLayout.addWidget(self.saveButton, 2, 11, 1, 1)

		self.advancedWidget = QtWidgets.QWidget(self.tabs)
		self.tabs.addTab(self.advancedWidget, "Advanced")

		self.advancedWidget.setObjectName("advancedWidget")
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.advancedWidget.setSizePolicy(policy)

		self.advancedLayout = QtWidgets.QGridLayout(self.advancedWidget)
		self.advancedLayout.setObjectName("advancedLayout")
		self.advancedLayout.setContentsMargins(0, 0, 0, 0)

		self.textOutput = QtWidgets.QTextEdit(self.splitter)
		self.textOutput.setObjectName("textOutput")

		self.gridLayout.addWidget(self.splitter, 0, 0, 1, 1)

==> aleph-1.0.21-py3-none-any.whl: aleph/gui/ui_decomposition.py <==
from PySide2 import QtWidgets, QtCore, QtWebEngineWidgets, QtGui
from OpenGL import GL

import os

class Ui_Decomposition:
	def setupUI(self, Decomposition):

		self.gridLayout = QtWidgets.QGridLayout(Decomposition)
		self.gridLayout.setObjectName("gridLayout")

		self.splitter = QtWidgets.QSplitter(Decomposition)
		self.splitter.setObjectName("splitter")
		self.splitter.setOrientation(QtCore.Qt.Vertical)
		self.splitter.setHandleWidth(15)
		#self.splitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter.png")+");}");

		self.topGroupBox = QtWidgets.QGroupBox(self.splitter)
		self.topGroupBox.setObjectName("topGroupBox")
		self.topGroupBox.setTitle("Decomposition in compact groups")

		self.topLayout = QtWidgets.QGridLayout(self.topGroupBox)
		self.topLayout.setObjectName("topLayout")

		self.titleLabel = QtWidgets.QLabel(self.topGroupBox)
		self.titleLabel.setObjectName("titleLabel")
		self.titleLabel.setText("Job title")
		self.topLayout.addWidget(self.titleLabel, 0, 0, 1, 1)
		self.titleLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.titleLine.setObjectName("titleLine")
		self.titleLine.setFixedWidth(150)
		self.topLayout.addWidget(self.titleLine, 0, 1, 1, 1)

		self.pdbLabel = QtWidgets.QLabel(self.topGroupBox)
		self.pdbLabel.setObjectName("pdbLabel")
		self.pdbLabel.setText("Pdb")
		self.topLayout.addWidget(self.pdbLabel, 1, 0, 1, 1)
		self.pdbLine = QtWidgets.QLineEdit(self.topGroupBox)
		self.pdbLine.setObjectName("pdbLine")
		self.topLayout.addWidget(self.pdbLine, 1, 1, 1, 1)
		self.pdbLoad = QtWidgets.QPushButton(self.topGroupBox)
		self.pdbLoad.setObjectName("pdbLoad")
		self.pdbLoad.setText("Browse")
		self.topLayout.addWidget(self.pdbLoad, 1, 2, 1, 1)

		self.homogeinityCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.homogeinityCheck.setObjectName("homogeinityCheck")
		self.homogeinityCheck.setText("Homogeneity")
		self.topLayout.addWidget(self.homogeinityCheck, 2, 0, 1, 2)

		self.packCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.packCheck.setObjectName("packCheck")
		self.packCheck.setText("Pack beta sheet")
		self.topLayout.addWidget(self.packCheck, 3, 0, 1, 2)

		self.iterativeCheck = QtWidgets.QCheckBox(self.topGroupBox)
		self.iterativeCheck.setObjectName("iterativeCheck")
		self.iterativeCheck.setText("Iterative hierarchical clustering")
		self.topLayout.addWidget(self.iterativeCheck, 4, 0, 1, 2)

		self.line = QtWidgets.QFrame(self.topGroupBox)
		self.line.setFrameShape(QtWidgets.QFrame.VLine)
		self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line.setObjectName("line")
		self.topLayout.addWidget(self.line, 0, 3, 5, 1)

		self.alphaLabel = QtWidgets.QLabel(self.topGroupBox)
		self.alphaLabel.setObjectName("alphaLabel")
		self.alphaLabel.setText("strictness alpha")
		self.topLayout.addWidget(self.alphaLabel, 0, 4, 1, 1)
		self.alphaSlider = QtWidgets.QSlider(self.topGroupBox)
		self.alphaSlider.setObjectName("alphaSlider")
		self.alphaSlider.setOrientation(QtCore.Qt.Horizontal)
		self.alphaSlider.setMinimum(0)
		self.alphaSlider.setMaximum(100)
		self.alphaSlider.setSingleStep(10)
		self.alphaSlider.setValue(50)
		self.topLayout.addWidget(self.alphaSlider, 0, 5, 1, 1)
		self.alphaValue = QtWidgets.QLabel(self.topGroupBox)
		self.alphaValue.setObjectName("valueAlpha")
		self.alphaValue.setText("0.50")
		self.topLayout.addWidget(self.alphaValue, 0, 6, 1, 1)

		self.betaLabel = QtWidgets.QLabel(self.topGroupBox)
		self.betaLabel.setObjectName("betaLabel")
		self.betaLabel.setText("strictness beta")
		self.topLayout.addWidget(self.betaLabel, 1, 4, 1, 1)
		self.betaSlider = QtWidgets.QSlider(self.topGroupBox)
		self.betaSlider.setObjectName("betaSlider")
		self.betaSlider.setOrientation(QtCore.Qt.Horizontal)
		self.betaSlider.setMinimum(0)
		self.betaSlider.setMaximum(100)
		self.betaSlider.setSingleStep(10)
		self.betaSlider.setValue(30)
		self.topLayout.addWidget(self.betaSlider, 1, 5, 1, 1)
		self.betaValue = QtWidgets.QLabel(self.topGroupBox)
		self.betaValue.setObjectName("betaValue")
		self.betaValue.setText("0.30")
		self.topLayout.addWidget(self.betaValue, 1, 6, 1, 1)

		self.algorithmLabel = QtWidgets.QLabel(self.topGroupBox)
		self.algorithmLabel.setObjectName("algorithmLabel")
		self.algorithmLabel.setText("Algorithm")
		self.topLayout.addWidget(self.algorithmLabel, 2, 4, 1, 1)	
		self.algorithmValue = QtWidgets.QComboBox(self.topGroupBox)
		self.algorithmValue.setObjectName("algorithmValue")
		self.algorithmValue.addItems(["fastgreedy" , "infomap" ,"eigenvectors" ,"label_propagation" ,"community_multilevel" ,"edge_betweenness" ,"spinglass" ,"walktrap"])
		self.topLayout.addWidget(self.algorithmValue, 2, 5, 1, 1)
		
		self.tabs = QtWidgets.QTabWidget(self.splitter)
		self.tabs.setObjectName("tabs")

		self.middleSplitter = QtWidgets.QSplitter(self.tabs)
		self.middleSplitter.setObjectName("middleSplitter")
		self.middleSplitter.setOrientation(QtCore.Qt.Horizontal)
		self.middleSplitter.setHandleWidth(10)
		#self.middleSplitter.setStyleSheet("QSplitter::handle{image:url("+os.path.join(os.path.dirname(__file__),"img/splitter_h.png")+");}");
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.middleSplitter.setSizePolicy(policy)

		self.tabs.addTab(self.middleSplitter, "General")
		
		self.tree = QtWidgets.QTreeView(self.middleSplitter)
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
		self.tree.setSizePolicy(policy)
		self.model = QtWidgets.QFileSystemModel(self.tree)
		self.tree.setModel(self.model)
		self.model.setNameFilters(["*.pdb", "*.ent"])
		self.model.setNameFilterDisables(False)
		self.tree.hideColumn(1)
		self.tree.hideColumn(2)
		self.tree.header().hide()
		self.tree.header().setSectionResizeMode(QtWidgets.QHeaderView.Stretch)
		self.tree.sortByColumn(3, QtCore.Qt.AscendingOrder)
		self.tree.setSortingEnabled(True)
		
		self.structureLayoutWidget = QtWidgets.QWidget(self.middleSplitter)
		self.structureLayoutWidget.setObjectName("structureLayoutWidget")

		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.structureLayoutWidget.setSizePolicy(policy)

		self.structureLayout = QtWidgets.QGridLayout(self.structureLayoutWidget)
		self.structureLayout.setObjectName("structureLayout")
		self.structureLayout.setContentsMargins(0, 0, 0, 0)

		self.browserLabel = QtWidgets.QLabel(self.structureLayoutWidget)
		self.browserLabel.setObjectName("browserLabel")
		self.browserLabel.setText("Decomposed model")
		self.structureLayout.addWidget(self.browserLabel, 0, 0, 1, 12)		

		self.browser = QtWebEngineWidgets.QWebEngineView(self.structureLayoutWidget)
		self.browser.setObjectName("browser")
		self.browser.page().setBackgroundColor(QtCore.Qt.black)
		self.browser.setSizePolicy(policy)

		self.structureLayout.addWidget(self.browser, 1, 0, 1, 12)

		spacerItem = QtWidgets.QSpacerItem(40 ,20 ,QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
		self.structureLayout.addItem(spacerItem, 2, 0, 1, 1)

		self.representationLabel = QtWidgets.QLabel(self.structureLayoutWidget)
		self.representationLabel.setObjectName("representationLabel")
		self.representationLabel.setText("Representation")
		self.structureLayout.addWidget(self.representationLabel, 2, 1, 1, 1)
		self.representationValue = QtWidgets.QComboBox(self.structureLayoutWidget)
		self.representationValue.setObjectName("representationValue")
		self.representationValue.addItems(["cartoon" , "backbone", "licorice", "line"])
		self.structureLayout.addWidget(self.representationValue, 2, 2, 1, 1)

		self.line1 = QtWidgets.QFrame(self.structureLayoutWidget)
		self.line1.setFrameShape(QtWidgets.QFrame.VLine)
		self.line1.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line1.setObjectName("line1")
		self.structureLayout.addWidget(self.line1, 2, 3, 1, 1)

		self.templateCheck = QtWidgets.QCheckBox(self.structureLayoutWidget)
		self.templateCheck.setObjectName("templateCheck")
		self.templateCheck.setText("Show template")
		self.structureLayout.addWidget(self.templateCheck, 2, 4, 1, 1)
		self.templateValue = QtWidgets.QComboBox(self.structureLayoutWidget)
		self.templateValue.setObjectName("templateValue")
		self.templateValue.addItems(["cartoon" , "backbone", "licorice", "line"])
		self.structureLayout.addWidget(self.templateValue, 2, 5, 1, 1)

		self.line2 = QtWidgets.QFrame(self.structureLayoutWidget)
		self.line2.setFrameShape(QtWidgets.QFrame.VLine)
		self.line2.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line2.setObjectName("line2")
		self.structureLayout.addWidget(self.line2, 2, 6, 1, 1)

		self.numberLabel = QtWidgets.QLabel(self.structureLayoutWidget)
		self.numberLabel.setObjectName("numberLabel")
		self.numberLabel.setText("Division cut to")
		self.structureLayout.addWidget(self.numberLabel, 2, 7, 1, 1)
		self.numberValue = QtWidgets.QSpinBox(self.structureLayoutWidget)
		self.numberValue.setObjectName("maxRmsdValue")
		self.numberValue.setValue(0)
		self.numberValue.setMaximum(999)
		self.numberValue.setEnabled(False)
		self.structureLayout.addWidget(self.numberValue, 2, 8, 1, 1)
		self.number2Label = QtWidgets.QLabel(self.structureLayoutWidget)
		self.number2Label.setObjectName("number2Label")
		self.number2Label.setText("cluster")
		self.structureLayout.addWidget(self.number2Label, 2, 9, 1, 1)

		self.line3 = QtWidgets.QFrame(self.structureLayoutWidget)
		self.line3.setFrameShape(QtWidgets.QFrame.VLine)
		self.line3.setFrameShadow(QtWidgets.QFrame.Sunken)
		self.line3.setObjectName("line3")
		self.structureLayout.addWidget(self.line3, 2, 10, 1, 1)

		self.saveButton = QtWidgets.QPushButton(self.structureLayoutWidget)
		self.saveButton.setObjectName("saveButton")
		self.saveButton.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(__file__),"img/screenshot.png")))
		self.structureLayout.addWidget(self.saveButton, 2, 11, 1, 1)

		self.advancedWidget = QtWidgets.QWidget(self.tabs)
		self.tabs.addTab(self.advancedWidget, "Advanced")

		self.advancedWidget.setObjectName("advancedWidget")
		policy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
		self.advancedWidget.setSizePolicy(policy)

		self.advancedLayout = QtWidgets.QGridLayout(self.advancedWidget)
		self.advancedLayout.setObjectName("advancedLayout")
		self.advancedLayout.setContentsMargins(0, 0, 0, 0)

		self.textOutput = QtWidgets.QTextEdit(self.splitter)
		self.textOutput.setObjectName("textOutput")

		self.gridLayout.addWidget(self.splitter, 0, 0, 1, 1)
